
#line 3 "lex.yy.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart(yyin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

extern int yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart (FILE *input_file  );
void yy_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer (FILE *file,int size  );
void yy_delete_buffer (YY_BUFFER_STATE b  );
void yy_flush_buffer (YY_BUFFER_STATE b  );
void yypush_buffer_state (YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state (void );

static void yyensure_buffer_stack (void );
static void yy_load_buffer_state (void );
static void yy_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER yy_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE yy_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes (yyconst char *bytes,int len  );

void *yyalloc (yy_size_t  );
void *yyrealloc (void *,yy_size_t  );
void yyfree (void *  );

#define yy_new_buffer yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

typedef unsigned char YY_CHAR;

FILE *yyin = (FILE *) 0, *yyout = (FILE *) 0;

typedef int yy_state_type;

extern int yylineno;

int yylineno = 1;

extern char *yytext;
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 151
#define YY_END_OF_BUFFER 152
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[617] =
    {   0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,  152,  151,
      139,  150,  151,  139,  134,  146,  139,  146,  146,  105,
      105,  105,  105,  105,  139,  134,  148,  139,  113,  148,
      148,  148,  130,  148,   99,   99,   99,   99,   99,   99,
       99,   99,   99,   99,   99,   99,   99,   99,   99,   99,
       99,   99,   99,  139,  134,  140,  139,  140,  140,  106,
      106,  106,  106,   15,   16,  139,  134,  141,  139,  141,
      141,  107,  107,  107,  107,  107,   28,   29,  139,  134,

      145,  139,   54,   55,   58,  145,   59,   56,   57,   60,
      139,  134,  143,  139,   42,   43,   46,  143,   47,   44,
       45,  139,  134,  144,  139,   48,   49,   52,  144,   53,
       50,   51,  139,  134,  142,  139,  111,  142,   13,   14,
      139,  134,  137,  137,  112,   61,   62,  137,  137,  134,
      149,  139,  149,  139,  134,  147,  139,  147,  139,  134,
       34,   35,  100,  100,  100,  100,  100,  104,  101,  102,
      103,  139,  136,  135,  139,  134,  134,  134,    0,  108,
        0,  105,  105,  105,  105,  105,  113,    0,    0,  123,
        0,    0,  132,  131,  130,   92,   99,   99,   99,   99,

       99,   99,   99,   99,   99,   99,   99,   99,   99,   99,
       99,   99,   99,   99,   99,   99,   99,   99,   99,   99,
       99,   99,   99,   99,   99,   99,   99,   99,    0,  109,
        0,  106,  106,  106,  106,  106,  106,    0,  110,    0,
      107,  107,  107,  107,  107,  111,    0,  138,  112,    0,
      138,  100,  100,  100,  100,  100,  100,  104,    0,  135,
      134,  105,  105,  105,  105,  114,    0,    0,  114,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
       93,  131,   99,   99,   87,   99,   99,   99,   99,   99,
       99,   99,   99,   99,   99,   76,   99,   99,   99,   99,

       99,   99,   99,   99,   99,   99,   99,   99,   99,   99,
       99,   99,   99,   99,   99,   99,   99,   99,  106,  106,
      106,  106,  106,  106,  107,  107,  107,  107,  100,  100,
      100,  100,  100,  100,  134,  105,  105,  105,  105,  129,
      125,  124,  126,    0,  127,  122,  115,  116,  117,  118,
      119,  120,  121,    0,   99,   99,   99,   99,   99,   99,
       65,   74,   99,   99,   99,   83,   99,   99,   99,   99,
       77,   99,   99,   99,   99,   99,   99,   99,   99,   99,
       99,   99,   99,   99,   99,   99,   99,   99,   99,   99,
       82,   99,  106,  106,  106,  106,  106,  106,  106,  106,

      106,  106,  107,  107,  107,  107,  100,   36,  100,  100,
      100,  100,  134,    1,  105,  105,    3,  127,  128,   99,
       99,   99,   99,   99,   99,   99,   84,   72,   99,   99,
       80,   99,   99,   99,   99,   99,   99,   99,   99,   99,
       75,   99,   99,    7,   99,   99,   99,   96,   99,   86,
       99,   97,   99,   99,  106,  106,  106,  106,  106,  106,
      106,  106,  106,  106,   21,   30,  107,  107,   33,  100,
       39,  100,  100,   37,  134,  105,  105,   99,   99,   99,
       99,   99,   99,   99,   81,   68,   63,   69,   99,   99,
       99,   99,   99,   90,   99,   99,   78,   67,   85,   99,

       99,   99,   99,   99,  106,  106,  106,  106,  106,  106,
      106,  106,   17,  106,  107,  107,  100,  100,   38,  134,
      105,  105,   99,   99,   99,   99,   99,   12,   99,   95,
       99,   99,   88,   99,   99,    6,   99,   64,   99,   71,
       99,  106,  106,  106,  106,  106,   27,   19,  106,   20,
      107,  107,  100,  100,  134,  134,  105,    4,   99,   11,
       99,   99,   99,   99,   99,   91,   99,   66,   94,   79,
       73,  106,   26,  106,  106,  106,  106,  107,   31,  100,
      100,  133,    2,   99,    5,   99,   99,   99,   98,   89,
      106,   23,  106,  106,   18,   32,  100,  100,   99,   99,

       99,   70,  106,  106,  106,   40,   41,   99,   10,    9,
      106,   25,   24,    8,   22,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    2,    3,    4,
        1,    2,    2,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    3,    1,    5,    6,    1,    1,    1,    7,    8,
        9,   10,    1,   11,    1,   12,   13,   14,   15,   15,
       15,   15,   15,   15,   15,   16,   16,   17,   18,   19,
        1,   20,    1,    1,   21,   22,   23,   24,   25,   26,
       27,   28,   29,   30,   28,   31,   32,   33,   34,   35,
       36,   37,   38,   39,   40,   41,   42,   28,   43,   28,
       44,   45,   46,    1,   47,    1,   48,   49,   50,   51,

       52,   53,   54,   55,   56,   28,   28,   57,   58,   59,
       60,   61,   28,   62,   63,   64,   65,   66,   67,   68,
       69,   28,   70,    1,   71,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[72] =
    {   0,
        1,    1,    1,    2,    3,    1,    4,    1,    1,    1,
        1,    1,    1,    5,    5,    5,    1,    1,    1,    1,
        5,    5,    5,    5,    5,    5,    6,    6,    6,    6,
        6,    6,    6,    6,    6,    6,    6,    6,    6,    6,
        6,    6,    6,    1,    1,    1,    6,    5,    5,    5,
        5,    5,    5,    6,    6,    6,    6,    6,    6,    6,
        6,    6,    6,    6,    6,    6,    6,    6,    6,    1,
        1
    } ;

static yyconst flex_int16_t yy_base[644] =
    {   0,
        0,    3,   16,    5,   87,    9,  158,  229,  300,  176,
      370,  440,  181,  510,  249,  555,  207,  211,  600,  645,
      252,  281,  267,  383,  691,  185,  389,  402, 1191, 1192,
      178, 1192,  183,  220, 1139, 1192,  184,  372,  185,    0,
     1132, 1140, 1135, 1123,  416, 1134, 1192,  198, 1139,  243,
      409,  195,  414, 1166,    0, 1146, 1134,  196,  376, 1120,
      204,  229, 1120, 1118, 1112, 1128, 1114,  214, 1122,  383,
      400,  317,  339,  454, 1122, 1192,  204,  422,  399,    0,
     1136,  370,  240, 1192, 1192,  459, 1120, 1192,  461,  429,
      458,    0, 1113, 1121, 1116, 1104, 1192, 1192,  470, 1115,

     1192,  475, 1192, 1192, 1192,  469, 1192, 1192, 1192, 1192,
      485, 1114, 1192,  478, 1192, 1192, 1192,  479, 1192, 1192,
     1192,  491, 1113, 1192,  493, 1192, 1192, 1192,  488, 1192,
     1192, 1192,  497, 1112, 1192,  502, 1117,  496, 1192, 1192,
      523, 1110, 1192,  505, 1115, 1192, 1192,  507,  528, 1108,
     1192,  530,  514,  533, 1107, 1192,  535,  530,  539, 1106,
     1192, 1192,    0, 1131, 1130,  427, 1117, 1108, 1192, 1192,
     1192,  544, 1192,    0,  546,    0,    0, 1100,  440, 1192,
     1147,    0, 1102, 1091, 1090, 1091, 1101,  546, 1138, 1137,
      758, 1131,  555,  560,  565, 1192,    0, 1095, 1085, 1082,

     1075, 1090, 1089, 1077, 1070, 1069, 1069, 1072, 1075,  318,
     1071, 1065, 1070, 1075,  522, 1077, 1071, 1064, 1069, 1062,
      505, 1063, 1058, 1058,  427, 1062, 1055,  527,  465, 1192,
     1112,    0, 1068,  529, 1065, 1059, 1052,  470, 1192, 1107,
        0, 1062, 1051, 1050, 1051, 1061,  582,  588, 1060,  588,
      592,    0, 1066,  363, 1066, 1068, 1072, 1055,  592,    0,
     1046, 1035, 1045, 1035, 1036, 1192, 1087, 1086, 1085,  600,
      603, 1084, 1083, 1082, 1081, 1080, 1079, 1078, 1077, 1076,
     1192,  607,  601, 1023,    0, 1021, 1018, 1016, 1015, 1028,
     1018, 1023, 1026, 1021, 1016,    0, 1017, 1022, 1017, 1006,

     1001, 1002, 1008, 1008, 1001, 1003,  997,  996,  994,  997,
      997, 1004,  995,  998,  994,  988, 1000, 1002,  607,  983,
      984,  990,  987,  981,  981,  991,  981,  982, 1011, 1015,
     1013, 1008,  999,  996,  978,  970,  969,  974,  976, 1192,
     1192, 1192, 1192,  645, 1192, 1192, 1192, 1192, 1192, 1192,
     1192, 1192, 1192, 1022,  997,  994,  584,  989, 1000,  967,
        0,    0,  960,  958,  964,    0,  958,  955,  959,  958,
        0,  967,  952,  966,  965,  960,  955,  947,  945,  564,
      945,  951,  956,  948,  937,  952,  943,  947,  946,  934,
        0,  934,  966,  963,  615,  958,  969,  945,  940,  935,

      942,  926,  925,  924,  929,  931,  957,    0,  944,  947,
      956,  955,  920,    0,  917,  929,    0, 1192, 1192,  955,
      935,  944,  948,  938,  932,  914,    0,    0,  917,  909,
        0,  916,  914,  908,  899,  888,  882,  891,  890,  869,
        0,  875,  876,    0,  876,  854,  862,    0,  850,    0,
      838,    0,  848,  832,  861,  785,  793,  796,  785,  779,
      752,  765,  764,  756,    0,    0,  751,  762,    0,  776,
        0,  769,  781,    0,  752,  754,  737,  762,  767,  773,
      760,  761,  757,  735,    0,    0,    0,    0,  741,  744,
      731,  738,  725,    0,  736,  724,    0,    0,    0,  722,

      732,  732,  726,  725,  743,  748,  754,  741,  742,  738,
      723,  710,    0,  708,  722,  705,  747,  746,    0,  721,
      714,  638,  650,  649,  663,  648,  659,    0,  631,    0,
      632,  619,    0,  628,  617,    0,  626,    0,  626,    0,
      624,  637,  636,  650,  635,  646,    0,    0,  618,    0,
      619,  616,  645,  644,  618,  584,  610,    0,  632,    0,
      618,  626,  606,  593,  586,    0,  583,    0,    0,    0,
        0,  604,    0,  592,  599,  590,  560,  548,    0,  541,
      534, 1192,    0,  529,    0,  536,  516,  497,    0,    0,
      489,    0,  478,  420,    0,    0,  429,  412,  394,  378,

      347,    0,  272,  264,  223,    0,    0,  230,    0,    0,
      184,    0,    0,    0,    0, 1192,  826,  832,  838,  844,
      850,  856,  862,  868,  874,  880,  886,  888,  894,  900,
      902,  908,  910,  916,  918,  924,  930,  932,  938,  944,
      950,  953,  958
    } ;

static yyconst flex_int16_t yy_def[644] =
    {   0,
      617,  617,  616,    3,  616,    5,  618,  618,  616,    9,
      619,  619,  620,  620,  621,  621,  622,  622,  623,  623,
      624,  624,  625,  625,  616,   25,  617,  617,  616,  616,
      616,  616,  616,  616,  626,  616,  616,  627,  616,  628,
      628,  628,  628,  628,  616,  626,  616,  616,  629,  630,
      616,  616,  616,  616,  631,  631,  631,  631,  631,  631,
      631,  631,  631,  631,  631,  631,  631,  631,  631,  631,
      631,  631,  631,  616,  626,  616,  616,  632,  616,  633,
      633,  633,  633,  616,  616,  616,  626,  616,  616,  634,
      616,  635,  635,  635,  635,  635,  616,  616,  616,  626,

      616,  616,  616,  616,  616,  616,  616,  616,  616,  616,
      616,  626,  616,  616,  616,  616,  616,  616,  616,  616,
      616,  616,  626,  616,  616,  616,  616,  616,  616,  616,
      616,  616,  616,  626,  616,  616,  636,  616,  616,  616,
      616,  626,  616,  616,  637,  616,  616,  616,  616,  626,
      616,  616,  616,  616,  626,  616,  616,  616,  616,  626,
      616,  616,  638,  638,  638,  638,  638,  639,  616,  616,
      616,  616,  616,  640,  616,  626,  626,  626,  627,  616,
      627,  628,  628,  628,  628,  628,  629,  629,  616,  616,
      641,  616,  616,  616,  616,  616,  631,  631,  631,  631,

      631,  631,  631,  631,  631,  631,  631,  631,  631,  631,
      631,  631,  631,  631,  631,  631,  631,  631,  631,  631,
      631,  631,  631,  631,  631,  631,  631,  631,  632,  616,
      632,  633,  633,  633,  633,  633,  633,  634,  616,  634,
      635,  635,  635,  635,  635,  636,  636,  616,  637,  637,
      616,  638,  638,  638,  638,  638,  638,  639,  639,  640,
      626,  628,  628,  628,  628,  616,  616,  616,  616,  616,
      616,  616,  616,  616,  616,  616,  616,  616,  616,  642,
      616,  616,  631,  631,  631,  631,  631,  631,  631,  631,
      631,  631,  631,  631,  631,  631,  631,  631,  631,  631,

      631,  631,  631,  631,  631,  631,  631,  631,  631,  631,
      631,  631,  631,  631,  631,  631,  631,  631,  633,  633,
      633,  633,  633,  633,  635,  635,  635,  635,  638,  638,
      638,  638,  638,  638,  626,  628,  628,  628,  628,  616,
      616,  616,  616,  616,  616,  616,  616,  616,  616,  616,
      616,  616,  616,  642,  631,  631,  631,  631,  631,  631,
      631,  631,  631,  631,  631,  631,  631,  631,  631,  631,
      631,  631,  631,  631,  631,  631,  631,  631,  631,  631,
      631,  631,  631,  631,  631,  631,  631,  631,  631,  631,
      631,  631,  633,  633,  633,  633,  633,  633,  633,  633,

      633,  633,  635,  635,  635,  635,  638,  638,  638,  638,
      638,  638,  626,  628,  628,  628,  628,  616,  616,  631,
      631,  631,  631,  631,  631,  631,  631,  631,  631,  631,
      631,  631,  631,  631,  631,  631,  631,  631,  631,  631,
      631,  631,  631,  631,  631,  631,  631,  631,  631,  631,
      631,  631,  631,  631,  633,  633,  633,  633,  633,  633,
      633,  633,  633,  633,  633,  635,  635,  635,  635,  638,
      638,  638,  638,  638,  626,  628,  628,  631,  631,  631,
      631,  631,  631,  631,  631,  631,  631,  631,  631,  631,
      631,  631,  631,  631,  631,  631,  631,  631,  631,  631,

      631,  631,  631,  631,  633,  633,  633,  633,  633,  633,
      633,  633,  633,  633,  635,  635,  638,  638,  638,  643,
      628,  628,  631,  631,  631,  631,  631,  631,  631,  631,
      631,  631,  631,  631,  631,  631,  631,  631,  631,  631,
      631,  633,  633,  633,  633,  633,  633,  633,  633,  633,
      635,  635,  638,  638,  643,  643,  628,  628,  631,  631,
      631,  631,  631,  631,  631,  631,  631,  631,  631,  631,
      631,  633,  633,  633,  633,  633,  633,  635,  635,  638,
      638,  616,  628,  631,  631,  631,  631,  631,  631,  631,
      633,  633,  633,  633,  633,  635,  638,  638,  631,  631,

      631,  631,  633,  633,  633,  638,  638,  631,  631,  631,
      633,  633,  633,  631,  633,    0,  616,  616,  616,  616,
      616,  616,  616,  616,  616,  616,  616,  616,  616,  616,
      616,  616,  616,  616,  616,  616,  616,  616,  616,  616,
      616,  616,  616
    } ;

static yyconst flex_int16_t yy_nxt[1264] =
    {   0,
      616,   31,   31,   32,   31,   34,   32,   45,   35,  616,
       46,   74,   33,  616,   75,   33,   36,   37,   37,   32,
       38,   36,   36,   36,   36,   36,   36,   36,   39,   36,
       36,   36,   36,   36,   36,   36,   40,   40,   40,   40,
       40,   40,   40,   40,   40,   40,   40,   40,   40,   40,
       40,   40,   40,   40,   40,   40,   40,   40,   40,   36,
       36,   36,   40,   40,   40,   41,   40,   40,   40,   40,
       40,   40,   40,   40,   42,   40,   40,   40,   40,   43,
       44,   40,   40,   40,   40,   36,   36,   47,   48,   48,
       32,   49,   47,   50,   47,   47,   47,   47,   51,   52,

       53,   53,   53,   54,   47,   47,   47,   55,   55,   55,
       55,   55,   55,   55,   55,   55,   55,   55,   55,   55,
       55,   55,   55,   55,   55,   56,   55,   55,   55,   55,
       47,   47,   47,   57,   58,   55,   59,   60,   61,   62,
       55,   55,   63,   64,   65,   66,   67,   68,   69,   70,
       71,   72,   73,   55,   55,   55,   47,   47,   76,   77,
       77,   32,   78,   76,   76,   76,   76,   76,   76,   76,
       79,   76,   76,   76,   76,   76,   76,   76,   99,  172,
      172,  100,  114,  114,   32,  172,  172,   34,  115,  116,
       35,  117,  173,  118,  173,  174,   81,  174,  119,  172,

      172,   76,   76,   76,  173,  172,  172,  174,  136,  136,
       32,  137,  136,  141,   32,  137,  142,  615,   82,  138,
       83,  172,  175,  138,  120,  176,  121,   84,   85,   76,
       77,   86,   32,   78,   87,   76,   76,   76,   76,   76,
       76,   79,   76,   76,   76,   76,   76,   76,   76,  190,
      125,  125,   32,  152,  152,   32,  126,  127,  200,  128,
      201,  129,  206,  614,  153,  613,  130,   81,  157,  157,
       32,  207,   76,   76,   76,  215,  139,  140,  216,  158,
      139,  140,  152,  154,   32,  208,  155,  191,  612,   82,
      209,   83,  131,  153,  132,  236,  237,  611,   84,   85,

       88,   89,   89,   32,   90,   88,   88,   88,   88,   88,
       88,   88,   91,   88,   88,   88,   88,   88,   88,   88,
       92,   92,   92,   92,   92,   92,   92,   92,   92,   92,
       92,   92,   92,   92,   92,   92,   92,   92,   92,   92,
       92,   92,   92,   88,   88,   88,   92,   92,   92,   93,
       92,   92,   92,   92,   92,   92,   92,   92,   94,   92,
       92,   92,   92,   95,   96,   92,   92,   92,   92,   97,
       98,  102,  102,   32,  295,  225,  180,  103,  104,  226,
      105,  296,  106,  330,  157,  159,   32,  107,  160,  610,
       31,   31,   32,  168,  227,  158,  169,  170,  228,  171,

      331,   33,  609,   31,   34,   32,  168,   35,  173,  169,
      170,  174,  171,  108,   33,  109,  181,  172,  175,  608,
      192,  176,  193,  193,  193,  194,  230,  195,  195,  195,
      202,  234,  203,  239,  235,  204,  607,  218,  219,  220,
      110,  102,  111,   32,  180,  112,  221,  103,  104,  255,
      105,  222,  106,  606,  223,  172,  175,  107,  605,  176,
      172,  175,  172,  172,  176,  256,  231,  173,  224,  230,
      174,  172,  175,  240,  239,  176,  172,  172,  173,  172,
      172,  174,  313,  108,  181,  109,  172,  175,  173,  314,
      176,  174,  172,  175,  172,  172,  176,  173,  172,  175,

      174,  604,  176,  172,  172,  173,  248,  248,  174,  231,
      110,  114,  122,   32,  240,  123,  173,  115,  116,  174,
      117,  603,  118,  173,  172,  175,  174,  119,  176,  248,
      251,  172,  172,  176,  172,  175,  172,  172,  176,  173,
      172,  175,  174,  602,  176,  172,  172,  172,  175,  187,
      187,  176,  308,  120,  601,  121,  125,  133,   32,  600,
      134,  599,  126,  127,  598,  128,  309,  129,  193,  193,
      193,  597,  130,  282,  282,  282,  194,  301,  195,  195,
      195,  302,  317,  318,  320,  246,  246,  582,  321,  248,
      248,  249,  249,  248,  251,  258,  258,  176,  131,  596,

      132,  144,  144,   32,  145,  422,  343,  146,  147,  345,
      595,  442,  148,  344,  344,  443,  344,  344,  146,  147,
      282,  282,  282,  355,  423,  356,  594,  593,  556,  393,
      592,  394,  591,  590,  357,  358,  457,  589,  359,  588,
      395,  396,  587,  146,  397,  147,  144,  149,   32,  145,
      150,  418,  146,  147,  586,  458,  585,  148,  344,  344,
      584,  583,  556,  146,  147,  581,  580,  579,  578,  577,
      576,  575,  574,  573,  572,  571,  570,  569,  568,  567,
      566,  565,  564,  563,  562,  561,  560,  559,  146,  558,
      147,   30,   31,   31,   32,   30,   30,   30,  161,  162,

       30,   30,   30,   33,   30,   30,   30,   30,   30,   30,
       30,  163,  163,  163,  164,  163,  163,  163,  163,  163,
      163,  163,  163,  163,  163,  163,  163,  165,  166,  163,
      163,  163,  167,  163,   30,   30,   30,  163,  163,  163,
      163,  163,  163,  163,  163,  163,  163,  163,  163,  163,
      163,  163,  163,  163,  163,  163,  163,  163,  163,  163,
       30,   30,  268,  557,  269,  556,  554,  553,  552,  551,
      550,  270,  271,  549,  548,  547,  546,  545,  544,  543,
      542,  541,  540,  539,  538,  537,  536,  535,  534,  533,
      532,  531,  530,  529,  528,  527,  526,  525,  524,  523,

      522,  521,  272,  520,  519,  273,  274,  518,  517,  516,
      275,  515,  514,  513,  512,  511,  276,  510,  509,  277,
      508,  278,  507,  279,  506,  280,   30,   30,   30,   30,
       30,   30,   80,   80,   80,   80,   80,   80,  101,  101,
      101,  101,  101,  101,  113,  113,  113,  113,  113,  113,
      124,  124,  124,  124,  124,  124,  135,  135,  135,  135,
      135,  135,  143,  143,  143,  143,  143,  143,  151,  151,
      151,  151,  151,  151,  156,  156,  156,  156,  156,  156,
      177,  505,  177,  177,  177,  177,  179,  504,  179,  179,
      179,  179,  182,  182,  187,  503,  502,  187,  187,  187,

      189,  501,  189,  189,  189,  189,  197,  197,  229,  500,
      229,  229,  229,  229,  232,  232,  238,  499,  238,  238,
      238,  238,  241,  241,  246,  498,  497,  246,  246,  246,
      249,  496,  495,  249,  249,  249,  252,  252,  258,  494,
      493,  258,  258,  258,  260,  492,  260,  260,  260,  260,
      267,  491,  267,  267,  267,  267,  354,  354,  555,  490,
      555,  555,  555,  555,  489,  488,  487,  486,  485,  484,
      483,  482,  481,  480,  479,  478,  477,  476,  475,  474,
      473,  472,  471,  470,  469,  468,  467,  466,  465,  464,
      463,  462,  461,  460,  459,  456,  455,  454,  453,  452,

      451,  450,  449,  448,  447,  446,  445,  444,  441,  440,
      439,  438,  437,  436,  435,  434,  433,  432,  431,  430,
      429,  428,  427,  426,  425,  424,  421,  420,  419,  417,
      416,  415,  414,  413,  412,  411,  410,  409,  408,  407,
      406,  405,  404,  403,  402,  401,  400,  399,  398,  392,
      391,  390,  389,  388,  387,  386,  385,  384,  383,  382,
      381,  380,  379,  378,  377,  376,  375,  374,  373,  372,
      371,  370,  369,  368,  367,  366,  365,  364,  363,  362,
      361,  360,  340,  353,  352,  351,  350,  349,  348,  347,
      346,  342,  341,  340,  339,  338,  337,  336,  335,  259,

      334,  333,  332,  329,  250,  247,  328,  327,  326,  325,
      238,  324,  323,  322,  319,  229,  316,  315,  312,  311,
      310,  307,  306,  305,  304,  303,  300,  299,  298,  297,
      294,  293,  292,  291,  290,  289,  288,  287,  286,  285,
      284,  283,  281,  266,  266,  188,  265,  264,  263,  262,
      179,  261,  259,  257,  254,  253,  178,  178,  178,  250,
      178,  247,  178,  178,  178,  178,  245,  244,  243,  242,
      178,  233,  178,  217,  214,  213,  212,  211,  210,  205,
      199,  198,  196,  188,  178,  186,  185,  184,  183,  178,
      616,   29,  616,  616,  616,  616,  616,  616,  616,  616,

      616,  616,  616,  616,  616,  616,  616,  616,  616,  616,
      616,  616,  616,  616,  616,  616,  616,  616,  616,  616,
      616,  616,  616,  616,  616,  616,  616,  616,  616,  616,
      616,  616,  616,  616,  616,  616,  616,  616,  616,  616,
      616,  616,  616,  616,  616,  616,  616,  616,  616,  616,
      616,  616,  616,  616,  616,  616,  616,  616,  616,  616,
      616,  616,  616
    } ;

static yyconst flex_int16_t yy_chk[1264] =
    {   0,
        0,    1,    1,    1,    2,    2,    2,    4,    2,    0,
        4,    6,    1,    0,    6,    2,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,

        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,   10,   31,
       31,   10,   13,   13,   13,   37,   37,   26,   13,   13,
       26,   13,   33,   13,   39,   33,    7,   39,   13,   48,

       48,    7,    7,    7,   52,   77,   77,   52,   17,   17,
       17,   17,   18,   18,   18,   18,   18,  611,    7,   17,
        7,   34,   34,   18,   13,   34,   13,    7,    7,    8,
        8,    8,    8,    8,    8,    8,    8,    8,    8,    8,
        8,    8,    8,    8,    8,    8,    8,    8,    8,   50,
       15,   15,   15,   21,   21,   21,   15,   15,   58,   15,
       58,   15,   61,  608,   21,  605,   15,    8,   23,   23,
       23,   61,    8,    8,    8,   68,   17,   17,   68,   23,
       18,   18,   22,   22,   22,   62,   22,   50,  604,    8,
       62,    8,   15,   22,   15,   83,   83,  603,    8,    8,

        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,   11,   11,   11,  210,   72,   38,   11,   11,   72,
       11,  210,   11,  254,   24,   24,   24,   11,   24,  601,
       27,   27,   27,   27,   73,   24,   27,   27,   73,   27,

      254,   27,  600,   28,   28,   28,   28,   28,   79,   28,
       28,   79,   28,   11,   28,   11,   38,   45,   45,  599,
       51,   45,   51,   51,   51,   53,   78,   53,   53,   53,
       59,   82,   59,   90,   82,   59,  598,   70,   70,   70,
       11,   12,   12,   12,  179,   12,   70,   12,   12,  166,
       12,   71,   12,  597,   71,   74,   74,   12,  594,   74,
       86,   86,   89,   89,   86,  166,   78,   91,   71,  229,
       91,   99,   99,   90,  238,   99,  102,  102,  106,  114,
      114,  106,  225,   12,  179,   12,  111,  111,  118,  225,
      111,  118,  122,  122,  125,  125,  122,  129,  133,  133,

      129,  593,  133,  136,  136,  138,  144,  144,  138,  229,
       12,   14,   14,   14,  238,   14,  148,   14,   14,  148,
       14,  591,   14,  153,  141,  141,  153,   14,  141,  149,
      149,  152,  152,  149,  154,  154,  157,  157,  154,  158,
      159,  159,  158,  588,  159,  172,  172,  175,  175,  188,
      188,  175,  221,   14,  587,   14,   16,   16,   16,  586,
       16,  584,   16,   16,  581,   16,  221,   16,  193,  193,
      193,  580,   16,  194,  194,  194,  195,  215,  195,  195,
      195,  215,  228,  228,  234,  247,  247,  556,  234,  248,
      248,  250,  250,  251,  251,  259,  259,  251,   16,  578,

       16,   19,   19,   19,   19,  357,  270,   19,   19,  271,
      577,  380,   19,  270,  270,  380,  271,  271,   19,   19,
      282,  282,  282,  283,  357,  283,  576,  575,  556,  319,
      574,  319,  572,  567,  283,  283,  395,  565,  283,  564,
      319,  319,  563,   19,  319,   19,   20,   20,   20,   20,
       20,  344,   20,   20,  562,  395,  561,   20,  344,  344,
      559,  557,  555,   20,   20,  554,  553,  552,  551,  549,
      546,  545,  544,  543,  542,  541,  539,  537,  535,  534,
      532,  531,  529,  527,  526,  525,  524,  523,   20,  522,
       20,   25,   25,   25,   25,   25,   25,   25,   25,   25,

       25,   25,   25,   25,   25,   25,   25,   25,   25,   25,
       25,   25,   25,   25,   25,   25,   25,   25,   25,   25,
       25,   25,   25,   25,   25,   25,   25,   25,   25,   25,
       25,   25,   25,   25,   25,   25,   25,   25,   25,   25,
       25,   25,   25,   25,   25,   25,   25,   25,   25,   25,
       25,   25,   25,   25,   25,   25,   25,   25,   25,   25,
       25,   25,  191,  521,  191,  520,  518,  517,  516,  515,
      514,  191,  191,  512,  511,  510,  509,  508,  507,  506,
      505,  504,  503,  502,  501,  500,  496,  495,  493,  492,
      491,  490,  489,  484,  483,  482,  481,  480,  479,  478,

      477,  476,  191,  475,  473,  191,  191,  472,  470,  468,
      191,  467,  464,  463,  462,  461,  191,  460,  459,  191,
      458,  191,  457,  191,  456,  191,  617,  617,  617,  617,
      617,  617,  618,  618,  618,  618,  618,  618,  619,  619,
      619,  619,  619,  619,  620,  620,  620,  620,  620,  620,
      621,  621,  621,  621,  621,  621,  622,  622,  622,  622,
      622,  622,  623,  623,  623,  623,  623,  623,  624,  624,
      624,  624,  624,  624,  625,  625,  625,  625,  625,  625,
      626,  455,  626,  626,  626,  626,  627,  454,  627,  627,
      627,  627,  628,  628,  629,  453,  451,  629,  629,  629,

      630,  449,  630,  630,  630,  630,  631,  631,  632,  447,
      632,  632,  632,  632,  633,  633,  634,  446,  634,  634,
      634,  634,  635,  635,  636,  445,  443,  636,  636,  636,
      637,  442,  440,  637,  637,  637,  638,  638,  639,  439,
      438,  639,  639,  639,  640,  437,  640,  640,  640,  640,
      641,  436,  641,  641,  641,  641,  642,  642,  643,  435,
      643,  643,  643,  643,  434,  433,  432,  430,  429,  426,
      425,  424,  423,  422,  421,  420,  416,  415,  413,  412,
      411,  410,  409,  407,  406,  405,  404,  403,  402,  401,
      400,  399,  398,  397,  396,  394,  393,  392,  390,  389,

      388,  387,  386,  385,  384,  383,  382,  381,  379,  378,
      377,  376,  375,  374,  373,  372,  370,  369,  368,  367,
      365,  364,  363,  360,  359,  358,  356,  355,  354,  339,
      338,  337,  336,  335,  334,  333,  332,  331,  330,  329,
      328,  327,  326,  325,  324,  323,  322,  321,  320,  318,
      317,  316,  315,  314,  313,  312,  311,  310,  309,  308,
      307,  306,  305,  304,  303,  302,  301,  300,  299,  298,
      297,  295,  294,  293,  292,  291,  290,  289,  288,  287,
      286,  284,  280,  279,  278,  277,  276,  275,  274,  273,
      272,  269,  268,  267,  265,  264,  263,  262,  261,  258,

      257,  256,  255,  253,  249,  246,  245,  244,  243,  242,
      240,  237,  236,  235,  233,  231,  227,  226,  224,  223,
      222,  220,  219,  218,  217,  216,  214,  213,  212,  211,
      209,  208,  207,  206,  205,  204,  203,  202,  201,  200,
      199,  198,  192,  190,  189,  187,  186,  185,  184,  183,
      181,  178,  168,  167,  165,  164,  160,  155,  150,  145,
      142,  137,  134,  123,  112,  100,   96,   95,   94,   93,
       87,   81,   75,   69,   67,   66,   65,   64,   63,   60,
       57,   56,   54,   49,   46,   44,   43,   42,   41,   35,
       29,  616,  616,  616,  616,  616,  616,  616,  616,  616,

      616,  616,  616,  616,  616,  616,  616,  616,  616,  616,
      616,  616,  616,  616,  616,  616,  616,  616,  616,  616,
      616,  616,  616,  616,  616,  616,  616,  616,  616,  616,
      616,  616,  616,  616,  616,  616,  616,  616,  616,  616,
      616,  616,  616,  616,  616,  616,  616,  616,  616,  616,
      616,  616,  616,  616,  616,  616,  616,  616,  616,  616,
      616,  616,  616
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "moc.l"
/****************************************************************************
**
** Lexical analyzer for meta object compiler
**
** Created : 930417
**
** Copyright (C) 1992-2008 Trolltech ASA.  All rights reserved.
**
** This file is part of the TQt GUI Toolkit.
**
** This file may be used under the terms of the GNU General
** Public License versions 2.0 or 3.0 as published by the Free
** Software Foundation and appearing in the files LICENSE.GPL2
** and LICENSE.GPL3 included in the packaging of this file.
** Alternatively you may (at your option) use any later version
** of the GNU General Public License if such license has been
** publicly approved by Trolltech ASA (or its successors, if any)
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
** or contact the sales department at sales@trolltech.com.
**
** This file may be used under the terms of the Q Public License as
** defined by Trolltech ASA and appearing in the file LICENSE.TQPL
** included in the packaging of this file.  Licensees holding valid TQt
** Commercial licenses may use this file in accordance with the TQt
** Commercial License Agreement provided with the Software.
**
** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
** A PARTICULAR PURPOSE. Trolltech reserves all rights not granted
** herein.
**
*****************************************************************************/
#line 42 "moc.l"
#ifdef MOC_YACC_CODE

#ifdef MOC_MWERKS_PLUGIN
#ifdef Q_OS_MAC9
# define isascii(c)   ((int)( (unsigned int) (c) <= (unsigned char)0x7F ))
#endif
const char *buf_buffer = NULL;
long buf_size_total = 0, buf_index = 0;
#define YY_INPUT(buf, result, max_size) \
     { \
          if(buf_index < buf_size_total ) { \
              while(!isascii(buf_buffer[buf_index])) buf_index++; \
              int ms = ((max_size < buf_size_total) ? max_size : buf_size_total); \
              for(result = 0; result < ms; result++) { \
                 char c = buf_buffer[buf_index + result]; \
                 if(!isascii(c)) { \
                    buf_index++; \
                    break; \
                 } \
                 buf[result] = c == '\r' ? '\n' : c; \
              } \
              buf_index += result; \
          } else result = YY_NULL; \
     }
#endif

#include "ntqstring.h"


#define input yyinput				// yyinput in C++

#define X if(lexDebug){fprintf(stderr,"LEX (%i) : %s\n",lineNo,yytext);};
#define Y if(lexDebug){fprintf(stderr,"LEX (%i) : %s\n",lineNo,yytext);};
/*
#define Y if(lexDebug){fprintf(stderr,"LEX (%i) : %s updates level to %i\n"\
                                 ,lineNo,yytext,templLevel);};
*/
#define Z if(lexDebug){fprintf(stderr,"LEX (%i) : skipped the string %s\"\n"\
                               ,lineNo,yytext);};
#define BEGIN_INSIDE


#define linput() \
    ( (c = input()) == '\n' ? (lineNo++, c) : (c == EOF) ? 0 : c )

#include <string.h>
#include <stdlib.h>

int classPLevel      = 1;  /* Depth of nested curly braces in IN_CLASS */
int namespacePLevel  = 1;  /* Depth of nested curly braces in IN_NAMESPACE */
int expLevel         = 1;  /* Depth of nested parentheses in IN_EXPR */
int enumLevel         = 1;  /* Depth of nested parentheses in IN_ENUM */
int fctLevel         = 1;  /* Depth of nested parentheses in IN_FCT */
int templLevel       = 1;  /* Depth of levels in IN_TEMPL_ARGS */

int lastState        = 0;  /* Remembers the state when a
                              MOC_SKIP_BEGIN is encountered */
int skipLevel        = 0; /* Depth of MOC_SKIP_BEGINs */

class TQString;

extern void addExpressionChar( const char );
extern void addExpressionString( const char * );
extern void moc_warn( const char *msg );

#line 1053 "lex.yy.c"

#define INITIAL 0
#define OUTSIDE 1
#define QT_DEF 2
#define IN_CLASS 3
#define IN_NAMESPACE 4
#define IN_ENUM 5
#define IN_EXPR 6
#define IN_DEF_ARG 7
#define IN_FCT 8
#define IN_TEMPL_ARGS 9
#define GIMME_SEMICOLON 10
#define SKIP 11
#define IN_PROPERTY 12
#define IN_CLASSINFO 13

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy (void );

int yyget_debug (void );

void yyset_debug (int debug_flag  );

YY_EXTRA_TYPE yyget_extra (void );

void yyset_extra (YY_EXTRA_TYPE user_defined  );

FILE *yyget_in (void );

void yyset_in  (FILE * in_str  );

FILE *yyget_out (void );

void yyset_out  (FILE * out_str  );

int yyget_leng (void );

char *yyget_text (void );

int yyget_lineno (void );

void yyset_lineno (int line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap (void );
#else
extern int yywrap (void );
#endif
#endif

    static void yyunput (int c,char *buf_ptr  );
    
#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, yyin))==0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	if ( yyleng > 0 ) \
		YY_CURRENT_BUFFER_LVALUE->yy_at_bol = \
				(yytext[yyleng - 1] == '\n'); \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 113 "moc.l"


#line 1259 "lex.yy.c"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer(yyin,YY_BUF_SIZE );
		}

		yy_load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
		yy_current_state += YY_AT_BOL();
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 617 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 1192 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 115 "moc.l"
{ X;
				  BEGIN QT_DEF;
				  return CLASS; }
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 118 "moc.l"
{ X;
				  BEGIN QT_DEF;
				  return NAMESPACE; }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 121 "moc.l"
{ X;
                                  BEGIN QT_DEF;
				  return USING; }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 124 "moc.l"
{ X;
				  BEGIN QT_DEF;
				  return TEMPLATE; }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 127 "moc.l"
{ X; return TQ_OBJECT; }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 128 "moc.l"
{ X; return SIGNALS; }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 129 "moc.l"
{ X; return SLOTS; }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 130 "moc.l"
{ X; return TQ_CLASSINFO; }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 131 "moc.l"
{ X; return TQ_PROPERTY; }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 132 "moc.l"
{ X; return TQ_OVERRIDE; }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 133 "moc.l"
{ X; return TQ_ENUMS; }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 134 "moc.l"
{ X; return TQ_SETS; }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 136 "moc.l"
{ fctLevel++;Y; }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 137 "moc.l"
{ fctLevel--;Y;if (fctLevel==0){X;return '}';}}
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 138 "moc.l"
{ classPLevel++;Y; }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 139 "moc.l"
{ classPLevel--;Y;if (classPLevel == 0)
                                                      {X;return '}';} }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 141 "moc.l"
{ X;if( classPLevel == 1 ) return PUBLIC; }
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 142 "moc.l"
{ X;if( classPLevel == 1 ) return PROTECTED; }
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 143 "moc.l"
{ X;if( classPLevel == 1 ) return PRIVATE; }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 144 "moc.l"
{ X;if( classPLevel == 1 ) return SIGNALS; }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 145 "moc.l"
{ X;if( classPLevel == 1 ) return SLOTS; }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 146 "moc.l"
{ X;if( classPLevel == 1 ) return TQ_CLASSINFO; }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 147 "moc.l"
{ X;
				  if ( classPLevel == 1 )
				      return TQ_OBJECT;
				  else if ( classPLevel > 1 )
				      moc_warn( "Cannot use TQ_OBJECT in nested class." );
				}
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 153 "moc.l"
{ X;if( classPLevel == 1 ) return TQ_PROPERTY; }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 154 "moc.l"
{ X;if( classPLevel == 1 ) return TQ_OVERRIDE; }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 155 "moc.l"
{ X;if( classPLevel == 1 ) return TQ_ENUMS; }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 156 "moc.l"
{ X;if( classPLevel == 1 ) return TQ_SETS; }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 158 "moc.l"
{ namespacePLevel++;Y; }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 159 "moc.l"
{ namespacePLevel--;Y;if (namespacePLevel == 0)
                                                          {X;return '}';}}
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 161 "moc.l"
{ X;
                                  BEGIN QT_DEF;
				  return CLASS; }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 164 "moc.l"
{ X;
                                  BEGIN QT_DEF;
                                  return TEMPLATE; }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 167 "moc.l"
{ X;
				  BEGIN QT_DEF;
				  return NAMESPACE; }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 170 "moc.l"
{ X;
                                  BEGIN QT_DEF;
				  return USING; }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 174 "moc.l"
{ X; return '('; }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 175 "moc.l"
{ X; return ')'; }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 176 "moc.l"
{ X; return READ; }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 177 "moc.l"
{ X; return WRITE; }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 178 "moc.l"
{ X; return STORED; }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 179 "moc.l"
{ X; return RESET; }
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 180 "moc.l"
{ X; return DESIGNABLE; }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 181 "moc.l"
{ X; return SCRIPTABLE; }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 184 "moc.l"
{ expLevel++;X; }
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 185 "moc.l"
{ expLevel--;Y;if (expLevel == 0)
					{ X; BEGIN QT_DEF; return ')';} }
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 187 "moc.l"
{ expLevel++;X; }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 188 "moc.l"
{ expLevel--;X;if (expLevel == 0)
					{ X; BEGIN QT_DEF; return ']';} }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 190 "moc.l"
{ if (expLevel == 0)
					{ X; BEGIN QT_DEF; return ',' ;} }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 192 "moc.l"
{ if (expLevel == 0)
					{ X; BEGIN QT_DEF; return ';' ;} }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 194 "moc.l"
{ expLevel++;X; }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 195 "moc.l"
{ expLevel--;Y;if (expLevel == 0)
					{ X; BEGIN QT_DEF; return ')';} }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 197 "moc.l"
{ expLevel++;X; }
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 198 "moc.l"
{ expLevel--;X;if (expLevel == 0)
					{ X; BEGIN QT_DEF; return ']';} }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 200 "moc.l"
{ if (expLevel <= 1)
					{ X; BEGIN QT_DEF; return ',' ;} }
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 202 "moc.l"
{ if (expLevel == 0)
					{ X; BEGIN QT_DEF; return ';' ;} }
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 204 "moc.l"
{ enumLevel++;X; }
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 205 "moc.l"
{ enumLevel--;X; }
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 206 "moc.l"
{ enumLevel++;X; }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 207 "moc.l"
{ enumLevel--;X }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 208 "moc.l"
{ if (enumLevel == 0)
					{ X; BEGIN QT_DEF; return ',' ;} }
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 210 "moc.l"
{ if (enumLevel == 0)
					{ X; BEGIN QT_DEF; return ';' ;} }
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 212 "moc.l"
{ if (enumLevel == 0)
					{ X; BEGIN QT_DEF; return '}' ;} }
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 214 "moc.l"
{ templLevel++;
				  Y;
				  addExpressionChar( yytext[0] );
				}
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 218 "moc.l"
{ templLevel--;
				  Y;
				  if ( templLevel == 0 ) {
				      X;
				      BEGIN QT_DEF;
				      return yytext[0];
				  } else {
				      addExpressionChar( yytext[0] );
				  }
				}
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 228 "moc.l"
{ X;return FRIEND; }
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 229 "moc.l"
{ X;return TYPEDEF; }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 230 "moc.l"
{ X;return AUTO; }
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 231 "moc.l"
{ X;return REGISTER; }
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 232 "moc.l"
{ X;return STATIC; }
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 233 "moc.l"
{ X;return EXTERN; }
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 234 "moc.l"
{ X;return INLINE; }
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 235 "moc.l"
{ X;return INLINE; }
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 236 "moc.l"
{ X;return VIRTUAL; }
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 237 "moc.l"
{ X;return CONST; }
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 238 "moc.l"
{ X;return VOLATILE; }
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 239 "moc.l"
{ X;return CHAR; }
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 240 "moc.l"
{ X;return SHORT; }
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 241 "moc.l"
{ X;return INT; }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 242 "moc.l"
{ X;return LONG; }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 243 "moc.l"
{ X;return SIGNED; }
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 244 "moc.l"
{ X;return UNSIGNED; }
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 245 "moc.l"
{ X;return FLOAT; }
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 246 "moc.l"
{ X;return DOUBLE; }
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 247 "moc.l"
{ X;return VOID; }
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 248 "moc.l"
{ X;return ENUM; }
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 249 "moc.l"
{ X;return CLASS; }
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 250 "moc.l"
{ X;return STRUCT; }
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 251 "moc.l"
{ X;return UNION; }
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 252 "moc.l"
{ X;return ASM; }
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 253 "moc.l"
{ X;return PRIVATE; }
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 254 "moc.l"
{ X;return PROTECTED; }
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 255 "moc.l"
{ X;return PUBLIC; }
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 256 "moc.l"
{ X;return OPERATOR; }
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 257 "moc.l"
{ X;return DBL_COLON; }
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 258 "moc.l"
{ X;return TRIPLE_DOT; }
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 259 "moc.l"
{ X;return TEMPLATE; }
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 260 "moc.l"
{ X;return MUTABLE; }
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 261 "moc.l"
{ X;return THROW; }
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 262 "moc.l"
{ X;return USING; }
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 263 "moc.l"
{ X;return NAMESPACE; }
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 265 "moc.l"
{
			  X;
			  yylval.string = tqstrdup(yytext);
			  return IDENTIFIER;
			}
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 271 "moc.l"
{
			  X;
			  yylval.string = tqstrdup(yytext);
			  return IDENTIFIER;
			}
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 277 "moc.l"
{ X; return '('; }
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 278 "moc.l"
{ X; return ')'; }
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 279 "moc.l"
{ X; return ','; }
	YY_BREAK
case 104:
/* rule 104 can match eol */
YY_RULE_SETUP
#line 281 "moc.l"
{
			  X;
			  yylval.string = tqstrdup( yytext + 1 );
			  input();		/* discard the '"' */
			  return STRING;
			}
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 288 "moc.l"
;
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 289 "moc.l"
;
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 290 "moc.l"
;
	YY_BREAK
case 108:
/* rule 108 can match eol */
YY_RULE_SETUP
#line 292 "moc.l"
{				/* discard strings */
			  Z;
			}
	YY_BREAK
case 109:
/* rule 109 can match eol */
YY_RULE_SETUP
#line 296 "moc.l"
{				/* discard strings */
			  Z;
			}
	YY_BREAK
case 110:
/* rule 110 can match eol */
YY_RULE_SETUP
#line 300 "moc.l"
{			/* discard strings */
			  Z;
			}
	YY_BREAK
case 111:
/* rule 111 can match eol */
YY_RULE_SETUP
#line 304 "moc.l"
{			/* discard strings */
			  Z;
			  addExpressionString( yytext );
			  input();		/* discard the '"' */
			}
	YY_BREAK
case 112:
/* rule 112 can match eol */
YY_RULE_SETUP
#line 311 "moc.l"
{
			  X;
			  addExpressionString( yytext );
			  input();		/* discard the '"' */
			  return STRING;
			}
	YY_BREAK
case 113:
/* rule 113 can match eol */
YY_RULE_SETUP
#line 318 "moc.l"
{
			  X;
			  yylval.string = tqstrdup( yytext + 1 );
			  input();		/* discard the '"' */
			  return STRING;
			}
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 325 "moc.l"
{ X;
			  yylval.char_val = yytext[1];
			  return CHAR_VAL;
			}
	YY_BREAK
case 115:
YY_RULE_SETUP
#line 330 "moc.l"
{ X;
			 yylval.char_val = '\a';
			 return CHAR_VAL;
		       }
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 335 "moc.l"
{ X;
			 yylval.char_val = '\b';
			 return CHAR_VAL;
		       }
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 340 "moc.l"
{ X;
			 yylval.char_val = '\f';
			 return CHAR_VAL;
		       }
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 345 "moc.l"
{ X;
			 yylval.char_val = '\n';
			 return CHAR_VAL;
		       }
	YY_BREAK
case 119:
YY_RULE_SETUP
#line 350 "moc.l"
{ X;
			 yylval.char_val = '\r';
			 return CHAR_VAL;
		       }
	YY_BREAK
case 120:
YY_RULE_SETUP
#line 355 "moc.l"
{ X;
			 yylval.char_val = '\t';
			 return CHAR_VAL;
		       }
	YY_BREAK
case 121:
YY_RULE_SETUP
#line 360 "moc.l"
{ X;
			 yylval.char_val = '\v';
			 return CHAR_VAL;
		       }
	YY_BREAK
case 122:
YY_RULE_SETUP
#line 365 "moc.l"
{ X;
			 yylval.char_val = '\\';
			 return CHAR_VAL;
		       }
	YY_BREAK
case 123:
YY_RULE_SETUP
#line 370 "moc.l"
{ X;
			 yylval.char_val = '\?';
			 return CHAR_VAL;
		       }
	YY_BREAK
case 124:
YY_RULE_SETUP
#line 375 "moc.l"
{ X;
			 yylval.char_val = '\'';
			 return CHAR_VAL;
		       }
	YY_BREAK
case 125:
YY_RULE_SETUP
#line 380 "moc.l"
{ X;
			 yylval.char_val = '\"';	/* " */
			 return CHAR_VAL;
		       }
	YY_BREAK
case 126:
YY_RULE_SETUP
#line 385 "moc.l"
{ X;
			 yylval.char_val = '\0';
			 return CHAR_VAL;
		       }
	YY_BREAK
case 127:
YY_RULE_SETUP
#line 390 "moc.l"
{ X;
			 yylval.char_val =
			   (char)strtol( &yytext[1], 0, 8 );
			 return CHAR_VAL;
		       }
	YY_BREAK
case 128:
YY_RULE_SETUP
#line 396 "moc.l"
{ X;
			 yylval.char_val =
			   (char)strtol( &yytext[2], 0, 16 );
			 return CHAR_VAL;
		       }
	YY_BREAK
case 129:
YY_RULE_SETUP
#line 402 "moc.l"
{ X;
			 yylval.char_val = ' ';
			 return CHAR_VAL;
		       }
	YY_BREAK
case 130:
YY_RULE_SETUP
#line 407 "moc.l"
{ X;
			  yylval.int_val = atoi(yytext);
			  return INT_VAL;
			}
	YY_BREAK
case 131:
YY_RULE_SETUP
#line 412 "moc.l"
{ X;
			  yylval.double_val = atof(yytext);
			  return DOUBLE_VAL;
			}
	YY_BREAK
case 132:
YY_RULE_SETUP
#line 417 "moc.l"
{ X;
			  yylval.double_val = atof(yytext);
			  return DOUBLE_VAL;
			}
	YY_BREAK
case 133:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 423 "moc.l"
{ /* skip multi-line macro-definitions */
			  int c, c1;
			  input();   /* Discard the '\n'. */
			  do {
			      c1=' ';
			      while((c = linput()) != '\n' && c != 0) c1=c;
			      if (c == 0) break;
			  } while(c1=='\\');
			  unput(c);  /* put back the '\n' or the EOF */
			}
	YY_BREAK
case 134:
YY_RULE_SETUP
#line 434 "moc.l"
{ /* preprocessor commands are skipped */}
	YY_BREAK
case 135:
YY_RULE_SETUP
#line 435 "moc.l"
{ /* C++ comment */
			  TQCString s = yytext;
                          if ( s.contains( "MOC_SKIP_BEGIN" ) ) {
                            skipLevel++;
                            if ( skipLevel == 1 ) {
                              lastState = YYSTATE;
                              BEGIN SKIP;
                            }
                          } else
                          if ( s.contains( "MOC_SKIP_END" ) ) {
                            if ( skipLevel == 0 ) {
                              moc_warn(" MOC_SKIP_END without MOC_SKIP_BEGIN");
                            } else {
                              skipLevel--;
                              if ( skipLevel == 0 ) {
                                BEGIN lastState;
                              }
                            }
                          }
                        }
	YY_BREAK
case 136:
YY_RULE_SETUP
#line 455 "moc.l"
{ /* C comment */
			  int c = ' ';
			  do {
			      if ( c!= '*' ) {
				  while((c = linput()) != '*' && c != 0)
				      ;
			      }
			      if (c == 0) break;
			  } while(((c = linput())) != '/' && c != 0);
			  if (c == 0)
			      unput(c);
			}
	YY_BREAK
case 137:
YY_RULE_SETUP
#line 468 "moc.l"
{ addExpressionChar( yytext[0] ); }
	YY_BREAK
case 138:
YY_RULE_SETUP
#line 470 "moc.l"
{
				    /* spaces are important in template args,
				       e.g. Foo<const int> */
				    addExpressionChar( yytext[0] ); }
	YY_BREAK
case 139:
YY_RULE_SETUP
#line 474 "moc.l"
;
	YY_BREAK
case 140:
YY_RULE_SETUP
#line 475 "moc.l"
;
	YY_BREAK
case 141:
YY_RULE_SETUP
#line 476 "moc.l"
;
	YY_BREAK
case 142:
YY_RULE_SETUP
#line 477 "moc.l"
;
	YY_BREAK
case 143:
YY_RULE_SETUP
#line 478 "moc.l"
{ addExpressionChar( yytext[0] ); }
	YY_BREAK
case 144:
YY_RULE_SETUP
#line 479 "moc.l"
;
	YY_BREAK
case 145:
YY_RULE_SETUP
#line 480 "moc.l"
{ addExpressionChar( yytext[0] ); }
	YY_BREAK
case 146:
YY_RULE_SETUP
#line 481 "moc.l"
;
	YY_BREAK
case 147:
YY_RULE_SETUP
#line 482 "moc.l"
;
	YY_BREAK
case 148:
YY_RULE_SETUP
#line 483 "moc.l"
{
			  X;
			  return yytext[0];
			}
	YY_BREAK
case 149:
YY_RULE_SETUP
#line 487 "moc.l"
{
			  X;
			  return ';';
			}
	YY_BREAK
case 150:
/* rule 150 can match eol */
YY_RULE_SETUP
#line 491 "moc.l"
{
			  lineNo++;
			}
	YY_BREAK
case 151:
YY_RULE_SETUP
#line 496 "moc.l"
ECHO;
	YY_BREAK
#line 2297 "lex.yy.c"
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(OUTSIDE):
case YY_STATE_EOF(QT_DEF):
case YY_STATE_EOF(IN_CLASS):
case YY_STATE_EOF(IN_NAMESPACE):
case YY_STATE_EOF(IN_ENUM):
case YY_STATE_EOF(IN_EXPR):
case YY_STATE_EOF(IN_DEF_ARG):
case YY_STATE_EOF(IN_FCT):
case YY_STATE_EOF(IN_TEMPL_ARGS):
case YY_STATE_EOF(GIMME_SEMICOLON):
case YY_STATE_EOF(SKIP):
case YY_STATE_EOF(IN_PROPERTY):
case YY_STATE_EOF(IN_CLASSINFO):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), (size_t) num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart(yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);
	yy_current_state += YY_AT_BOL();

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 617 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 617 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 616);

	return yy_is_jam ? 0 : yy_current_state;
}

    static void yyunput (int c, register char * yy_bp )
{
	register char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up yytext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		register int number_to_move = (yy_n_chars) + 2;
		register char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		register char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart(yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = (c == '\n');

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer(yyin,YY_BUF_SIZE );
	}

	yy_init_buffer(YY_CURRENT_BUFFER,input_file );
	yy_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree((void *) b->yy_ch_buf  );

	yyfree((void *) b  );
}

#ifndef __cplusplus
extern int isatty (int );
#endif /* __cplusplus */
    
/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (yyconst char * yystr )
{
    
	return yy_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (yyconst char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) yyalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
        
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void yyset_lineno (int  line_number )
{
    
    yylineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  in_str )
{
        yyin = in_str ;
}

void yyset_out (FILE *  out_str )
{
        yyout = out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  bdebug )
{
        yy_flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = (FILE *) 0;
    yyout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void yyfree (void * ptr )
{
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 496 "moc.l"



#endif // MOC_YACC_CODE

